package com.qianhe.system.controller;

import com.qianhe.common.annotation.Log;
import com.qianhe.common.core.controller.BaseController;
import com.qianhe.common.core.domain.AjaxResult;
import com.qianhe.common.core.page.TableDataInfo;
import com.qianhe.common.enums.BusinessType;
import com.qianhe.common.utils.poi.ExcelUtil;
import com.qianhe.system.domain.WaterSpe;
import com.qianhe.system.service.IWaterSpeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 商品规格Controller
 *
 * @author qianhe
 * @date 2023-11-23
 */
@RestController
@RequestMapping("/system/spe")
public class WaterSpeController extends BaseController
{
    @Autowired
    private IWaterSpeService waterSpeService;

    /**
     * 查询商品规格列表
     */
    @PreAuthorize("@ss.hasPermi('system:spe:list')")
    @GetMapping("/list")
    public TableDataInfo list(WaterSpe waterSpe)
    {
        startPage();
        List<WaterSpe> list = waterSpeService.selectWaterSpeList(waterSpe);
        return getDataTable(list);
    }

    /**
     * 导出商品规格列表
     */
    @PreAuthorize("@ss.hasPermi('system:spe:export')")
    @Log(title = "商品规格", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, WaterSpe waterSpe)
    {
        List<WaterSpe> list = waterSpeService.selectWaterSpeList(waterSpe);
        ExcelUtil<WaterSpe> util = new ExcelUtil<WaterSpe>(WaterSpe.class);
        util.exportExcel(response, list, "商品规格数据");
    }

    /**
     * 获取商品规格详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:spe:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(waterSpeService.selectWaterSpeById(id));
    }

    /**
     * 新增商品规格
     */
    @PreAuthorize("@ss.hasPermi('system:spe:add')")
    @Log(title = "商品规格", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody WaterSpe waterSpe)
    {
        return toAjax(waterSpeService.insertWaterSpe(waterSpe));
    }

    /**
     * 修改商品规格
     */
    @PreAuthorize("@ss.hasPermi('system:spe:edit')")
    @Log(title = "商品规格", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody WaterSpe waterSpe)
    {
        return toAjax(waterSpeService.updateWaterSpe(waterSpe));
    }

    /**
     * 删除商品规格
     */
    @PreAuthorize("@ss.hasPermi('system:spe:remove')")
    @Log(title = "商品规格", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(waterSpeService.deleteWaterSpeByIds(ids));
    }
}
