package com.qianhe.system.service.impl;

import com.qianhe.common.utils.DateUtils;
import com.qianhe.system.domain.WaterSpe;
import com.qianhe.system.mapper.WaterSpeMapper;
import com.qianhe.system.service.IWaterSpeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 商品规格Service业务层处理
 *
 * @author qianhe
 * @date 2023-11-23
 */
@Service
public class WaterSpeServiceImpl implements IWaterSpeService
{
    @Autowired
    private WaterSpeMapper waterSpeMapper;

    /**
     * 查询商品规格
     *
     * @param id 商品规格主键
     * @return 商品规格
     */
    @Override
    public WaterSpe selectWaterSpeById(Long id)
    {
        return waterSpeMapper.selectWaterSpeById(id);
    }

    /**
     * 查询商品规格列表
     *
     * @param waterSpe 商品规格
     * @return 商品规格
     */
    @Override
    public List<WaterSpe> selectWaterSpeList(WaterSpe waterSpe)
    {
        return waterSpeMapper.selectWaterSpeList(waterSpe);
    }

    /**
     * 新增商品规格
     *
     * @param waterSpe 商品规格
     * @return 结果
     */
    @Override
    public int insertWaterSpe(WaterSpe waterSpe)
    {
        waterSpe.setCreateTime(DateUtils.getNowDate());
        return waterSpeMapper.insertWaterSpe(waterSpe);
    }

    /**
     * 修改商品规格
     *
     * @param waterSpe 商品规格
     * @return 结果
     */
    @Override
    public int updateWaterSpe(WaterSpe waterSpe)
    {
        return waterSpeMapper.updateWaterSpe(waterSpe);
    }

    /**
     * 批量删除商品规格
     *
     * @param ids 需要删除的商品规格主键
     * @return 结果
     */
    @Override
    public int deleteWaterSpeByIds(Long[] ids)
    {
        return waterSpeMapper.deleteWaterSpeByIds(ids);
    }

    /**
     * 删除商品规格信息
     *
     * @param id 商品规格主键
     * @return 结果
     */
    @Override
    public int deleteWaterSpeById(Long id)
    {
        return waterSpeMapper.deleteWaterSpeById(id);
    }
}
